@@ -9,52 +9,57 @@ import unittest
 # import requests
 # from mock import patch
 
+from domonic import domonic
+
 from domonic.html import *
+from domonic.decorators import silence
 
 
 class domonicTestCase(unittest.TestCase):
 
-    # def test_domonic_parse(self):
-        # page = domonic.parse("<html><body>'some content'</body></html>")
-        # page = domonic.parse("<html><body></body></html>")
-        # print(page)
+    # @silence
+    def test_domonic_parse(self):
+        page = domonic.parse("<html><body>'some content'</body></html>")
+        page = domonic.parse("<html><body></body></html>")
+        print(page)
 
+    @silence
     def test_domonic_get(self):
         print("test_domonic_get-----------=-----------=-----------=-----------=-----------=-----------=-----------=")
-        # page = domonic.get("http://eventual.technology")
-        # page = domonic.get("https://v5.getbootstrap.com/docs/5.0/examples/checkout/")
-        # page = domonic.get("https://v5.getbootstrap.com/docs/5.0/examples/carousel/?#")
-        # page = domonic.get("https://v5.getbootstrap.com/docs/5.0/examples/dashboard/#")
-        # page = domonic.get("https://www.google.com")
-        # page = domonic.get("https://www.facebook.com")
-        # print("<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<")
-        # print(render(page))
+        page = domonic.get("http://eventual.technology")
+        page = domonic.get("https://v5.getbootstrap.com/docs/5.0/examples/checkout/")
+        page = domonic.get("https://v5.getbootstrap.com/docs/5.0/examples/carousel/?#")
+        page = domonic.get("https://v5.getbootstrap.com/docs/5.0/examples/dashboard/#")
+        page = domonic.get("https://www.google.com")
+        page = domonic.get("https://www.facebook.com")
+        print("<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<")
+        print(render(page))
         pass
 
-
+    @silence
     def test_domonic_render(self):
         test = html(
             head(
             meta(_charset="utf-8"),
-            # meta( **{"http-equiv":"X-UA-Compatible"},, _content="IE=edge"),
+            # meta(**{"http-equiv": "X-UA-Compatible"},, _content="IE=edge"),
             title("eventual.technology"),
             meta(_name="viewport", _content="width=device-width, initial-scale=1"),
-            meta(_name="description", _content="eventual technology" ),
-            meta(_name="keywords", _content="website, html5, javascript, python, software, aws" ),
-            meta(_name="author", _content="eventual.technology" ),
+            meta(_name="description", _content="eventual technology"),
+            meta(_name="keywords", _content="website, html5, javascript, python, software, aws"),
+            meta(_name="author", _content="eventual.technology"),
             meta(_property="og:title", _content="eventual technology"),
             meta(_property="og:image", _content=""),
             meta(_property="og:url", _content=""),
             meta(_property="og:site_name", _content="eventual.technology"),
             meta(_property="og:description", _content=""),
-            meta(_name="twitter:title", _content="eventual technology" ),
-            meta(_name="twitter:image", _content="" ),
-            meta(_name="twitter:url", _content="eventual.technology" ),
-            meta(_name="twitter:card", _content="" )
+            meta(_name="twitter:title", _content="eventual technology"),
+            meta(_name="twitter:image", _content=""),
+            meta(_name="twitter:url", _content="eventual.technology"),
+            meta(_name="twitter:card", _content="")
             ),
             body(
                 header(
-                    h1(a( _href="mailto:mike@eventual.technology")),
+                    h1(a(_href="mailto:mike@eventual.technology")),
                     h2("07535784121")
                 ),
                 footer(
@@ -66,53 +71,50 @@ class domonicTestCase(unittest.TestCase):
         # print(render(test))
         pass
 
-
+    @silence
     def test_domonic_render_head(self):
-        '''
         test = head(
-            meta( _charset="utf-8"),
-            # meta( **{"http-equiv":"X-UA-Compatible"},, _content="IE=edge"),
+            meta(_charset="utf-8"),
+            # meta(**{"http-equiv": "X-UA-Compatible"},, _content="IE=edge"),
             title("byteface"),
-            meta( _name="viewport", _content="width=device-width, initial-scale=1"),
-            meta( _name="description", _content="eventual technology" ),
-            meta( _name="keywords", _content="website, html5, javascript, python, software, aws" ),
-            meta( _name="author", _content="" ),
+            meta(_name="viewport", _content="width=device-width, initial-scale=1"),
+            meta(_name="description", _content="eventual technology"),
+            meta(_name="keywords", _content="website, html5, javascript, python, software, aws"),
+            meta(_name="author", _content=""),
 
-            meta( _property="og:title", _content=""),
-            meta( _property="og:image", _content=""),
-            meta( _property="og:url", _content=""),
-            meta( _property="og:site_name", _content=""),
-            meta( _property="og:description", _content=""),
-            meta( _property="og:type", _content="" ),
-            
-            meta( _name="twitter:title", _content="" ),
-            meta( _name="twitter:imag:src", _content="" ),
-            meta( _name="twitter:url", _content="" ),
-            meta( _name="twitter:card", _content="" ),
-            meta( _name="twitter:site", _content="" ),
-            meta( _name="twitter:description", _content="" ),
-  
-            # link( _rel="dns-prefetch", _href="https://github.githubassets.com" )
+            meta(_property="og:title", _content=""),
+            meta(_property="og:image", _content=""),
+            meta(_property="og:url", _content=""),
+            meta(_property="og:site_name", _content=""),
+            meta(_property="og:description", _content=""),
+            meta(_property="og:type", _content=""),
+
+            meta(_name="twitter:title", _content=""),
+            meta(_name="twitter:imag:src", _content=""),
+            meta(_name="twitter:url", _content=""),
+            meta(_name="twitter:card", _content=""),
+            meta(_name="twitter:site", _content=""),
+            meta(_name="twitter:description", _content=""),
+
+            # link(_rel="dns-prefetch", _href="https://github.githubassets.com")
             # TOOD - list of 'classless'
-            # link( _crossorigin="anonymous", _media="all", _integrity="sha512-1234", _rel="stylesheet", _href="styles.css" )
-            # link( _rel="search", _type="application/opensearchdescription+xml" href="/opensearch.xml" title="GitHub")
+            # link(_crossorigin="anonymous", _media="all", _integrity="sha512-1234", _rel="stylesheet", _href="styles.css")
+            # link(_rel="search", _type="application/opensearchdescription+xml" href="/opensearch.xml" title="GitHub")
 
-            meta( _property="fb:app_id", _content=""),
-            meta( _name="google-site-verification", _content="" ),
-            meta( _name="google-analytics", _content="" ),
-            meta( _name="hostname", _content="site.com"),
-            link( _rel="icon", _class="js-site-favicon", _type="image/png", _href="favicon.svg" ),
-            meta( _name="theme-color", _content="#1e2327" ),
-            link( _rel="manifest", _href="/manifest.json", _crossOrigin="use-credentials" ),
-            meta( _property="profile:username", _content="byteface" )
+            meta(_property="fb:app_id", _content=""),
+            meta(_name="google-site-verification", _content=""),
+            meta(_name="google-analytics", _content=""),
+            meta(_name="hostname", _content="site.com"),
+            link(_rel="icon", _class="js-site-favicon", _type="image/png", _href="favicon.svg"),
+            meta(_name="theme-color", _content="#1e2327"),
+            link(_rel="manifest", _href="/manifest.json", _crossOrigin="use-credentials"),
+            meta(_property="profile:username", _content="byteface")
         )
-        '''
-        # print(render(test))
+        print(render(test))
         pass
 
-
+    @silence
     def test_domonic_render_bs5_checkout(self):
-        '''
         test = html(
             head().html(
                 meta(_charset="utf-8"),
@@ -147,17 +149,15 @@ class domonicTestCase(unittest.TestCase):
                 """),
                 link(_href="form-validation.css", _rel="stylesheet"),
             ),
-            body(_class="bg-light").html( #, _html= # TODO - make an attribute to do the same
-                div(_class="container").html( 
+            body(_class="bg-light").html(  #, _html= # TODO - make an attribute to do the same
+                div(_class="container").html(
                     div(_class="py-5 text-center").html(
-                        img(_class="d-block mx-auto mb-4", 
-                            _src="/docs/5.0/assets/brand/bootstrap-solid.svg", 
-                            _alt="", 
-                            _width="72", 
-                            _height="72"
+                        img(_class="d-block mx-auto mb-4",
+                            _src="/docs/5.0/assets/brand/bootstrap-solid.svg",
+                            _alt="", _width="72", _height="72"
                             ),
                         h2("Checkout form"),
-                        p( "Below is an example form built entirely with Bootstrap’s form controls. \
+                        p("Below is an example form built entirely with Bootstrap’s form controls. \
                             Each required form group has a validation state that can be triggered \
                             by attempting to submit the form without completing it.",
                             _class="lead")
@@ -332,34 +332,31 @@ class domonicTestCase(unittest.TestCase):
                     script(_src="form-validation.js")
                 )
             )
-        )    
-        
+        )
+
         # print(render(test,'bs5_test_checkout.html'))
         print(render(test))
-        '''
         pass
 
-
-
+    @silence
     def test_domonic_render_bs5_carousel(self):
-        '''
         test = html(_lang="en").html(
             head(
-                meta( _charset="utf-8"),
-                meta( _name="viewport", _content="_width=device-width, initial-scale=1"),
-                meta( _name="description", _content=""),
-                meta( _name="author", _content="Mark Otto, Jacob Thornton, and Bootstrap contributors"),
-                meta( _name="generator", _content="Hugo 0.72.0"),
+                meta(_charset="utf-8"),
+                meta(_name="viewport", _content="_width=device-width, initial-scale=1"),
+                meta(_name="description", _content=""),
+                meta(_name="author", _content="Mark Otto, Jacob Thornton, and Bootstrap contributors"),
+                meta(_name="generator", _content="Hugo 0.72.0"),
                 title("Carousel Template · Bootstrap"),
-                link( _rel="canonical", _href="https://v5.getbootstrap.com/docs/5.0/examples/carousel/"),
-                link( _href="/docs/5.0/dist/css/bootstrap.min.css", _rel="stylesheet", _integrity="sha384-1234", _crossorigin="anonymous"),
-                link( _rel="apple-touch-icon", _href="/docs/5.0/assets/img/favicons/apple-touch-icon.png", _sizes="180x180"),
-                link( _rel="icon", _href="/docs/5.0/assets/img/favicons/favicon-32x32.png", _sizes="32x32", _type="image/png"),
-                link( _rel="icon", _href="/docs/5.0/assets/img/favicons/favicon-16x16.png", _sizes="16x16", _type="image/png"),
-                link( _rel="manifest", _href="/docs/5.0/assets/img/favicons/manifest.json"),
-                link( _rel="mask-icon", _href="/docs/5.0/assets/img/favicons/safari-pinned-tab.svg", _color="#7952b3"),
-                link( _rel="icon", _href="/docs/5.0/assets/img/favicons/favicon.ico"),
-                meta( _name="theme-color", _content="#7952b3"),
+                link(_rel="canonical", _href="https://v5.getbootstrap.com/docs/5.0/examples/carousel/"),
+                link(_href="/docs/5.0/dist/css/bootstrap.min.css", _rel="stylesheet", _integrity="sha384-1234", _crossorigin="anonymous"),
+                link(_rel="apple-touch-icon", _href="/docs/5.0/assets/img/favicons/apple-touch-icon.png", _sizes="180x180"),
+                link(_rel="icon", _href="/docs/5.0/assets/img/favicons/favicon-32x32.png", _sizes="32x32", _type="image/png"),
+                link(_rel="icon", _href="/docs/5.0/assets/img/favicons/favicon-16x16.png", _sizes="16x16", _type="image/png"),
+                link(_rel="manifest", _href="/docs/5.0/assets/img/favicons/manifest.json"),
+                link(_rel="mask-icon", _href="/docs/5.0/assets/img/favicons/safari-pinned-tab.svg", _color="#7952b3"),
+                link(_rel="icon", _href="/docs/5.0/assets/img/favicons/favicon.ico"),
+                meta(_name="theme-color", _content="#7952b3"),
                 style("""
                 .bd-placeholder-img {
                     font-size: 1.125rem;
@@ -375,63 +372,63 @@ class domonicTestCase(unittest.TestCase):
                     }
                 }
                 """),
-                link( _href="carousel.css", _rel="stylesheet"),
+                link(_href="carousel.css", _rel="stylesheet"),
             ),
             body(
                 header(
-                    nav( _class="navbar navbar-expand-md navbar-dark fixed-top bg-dark").html(
-                        div( _class="container-fluid").html(
+                    nav(_class="navbar navbar-expand-md navbar-dark fixed-top bg-dark").html(
+                        div(_class="container-fluid").html(
                             a("Carousel", _class="navbar-brand", _href="#"),
-                            button(span( _class="navbar-toggler-icon"), _class="navbar-toggler", _type="button", **{"_data-toggle":"collapse"}, **{"_data-target":"#navbarCollapse"}, **{"_aria-controls":"navbarCollapse"}, **{"_aria-expanded":"false"}, **{"_aria-label":"Toggle navigation"})
+                            button(span(_class="navbar-toggler-icon"), _class="navbar-toggler", _type="button", **{"_data-toggle": "collapse"}, **{"_data-target": "#navbarCollapse"}, **{"_aria-controls": "navbarCollapse"}, **{"_aria-expanded": "false"}, **{"_aria-label": "Toggle navigation"})
                         ),
-                        div( _class="collapse navbar-collapse", _id="navbarCollapse").html(
-                                ul( _class="navbar-nav mr-auto mb-2 mb-md-0").html(
-                                    li(a("Home", _class="nav-link", **{"_aria-current":"page"}, _href="#"), _class="nav-item active"),
+                        div(_class="collapse navbar-collapse", _id="navbarCollapse").html(
+                                ul(_class="navbar-nav mr-auto mb-2 mb-md-0").html(
+                                    li(a("Home", _class="nav-link", **{"_aria-current": "page"}, _href="#"), _class="nav-item active"),
                                     li(a("Link", _class="nav-link", _href="#"), _class="nav-item"),
-                                    li(a("Disabled", _class="nav-link disabled", _href="#", _tabindex="-1", **{"_aria-disabled":"true"}),
+                                    li(a("Disabled", _class="nav-link disabled", _href="#", _tabindex="-1", **{"_aria-disabled": "true"}),
                                     _class="nav-item"
                                     )
                                 ),
-                                form( _class="d-flex").html(
+                                form(_class="d-flex").html(
                                     input(button("Search", _class="btn btn-outline-success", _type="submit"),
-                                    _class="form-control mr-2", _type="search", _placeholder="Search", **{"_aria-label":"Search"},
+                                    _class="form-control mr-2", _type="search", _placeholder="Search", **{"_aria-label": "Search"},
                                 )
                             )
                         )
                     )
                 ),
                 main(
-                    div( _id="myCarousel", _class="carousel slide", **{"_data-ride":"carousel"}).html(
-                    ol( _class="carousel-indicators").html(
-                        li( **{"_data-target":"#myCarousel"}, **{"_data-slide-to":"0"}, _class="active"),
-                        li( **{"_data-target":"#myCarousel"}, **{"_data-slide-to":"1"}),
-                        li( **{"_data-target":"#myCarousel"}, **{"_data-slide-to":"2"})
+                    div(_id="myCarousel", _class="carousel slide", **{"_data-ride": "carousel"}).html(
+                    ol(_class="carousel-indicators").html(
+                        li(**{"_data-target": "#myCarousel"}, **{"_data-slide-to": "0"}, _class="active"),
+                        li(**{"_data-target": "#myCarousel"}, **{"_data-slide-to": "1"}),
+                        li(**{"_data-target": "#myCarousel"}, **{"_data-slide-to": "2"})
                     ),
-                    div( _class="carousel-inner").html(
-                    div( _class="carousel-item active").html(
+                    div(_class="carousel-inner").html(
+                    div(_class="carousel-item active").html(
                         """<svg _class="bd-placeholder-img", _width="100%", _height="100%" xmlns="http://www.w3.org/2000/svg" preserveAspectRatio="xMidYMid slice", _role="img" focusable="false",<rect _width="100%", _height="100%" fill="#777")</svg>""",
-                        div( _class="container").html(
-                            div( _class="carousel-caption text-left").html(
+                        div(_class="container").html(
+                            div(_class="carousel-caption text-left").html(
                                 h1("Example headline."),
                                 p("Cras justo odio, dapibus ac facilisis in, egestas eget quam. Donec id elit non mi porta gravida at eget metus. Nullam id dolor id nibh ultricies vehicula ut id elit."),
                                 p(a("Sign up today", _class="btn btn-lg btn-primary", _href="#", _role="button"))
                             )
                         )
                     ),
-                    div( _class="carousel-item").html(
+                    div(_class="carousel-item").html(
                         """<svg _class="bd-placeholder-img", _width="100%", _height="100%" xmlns="http://www.w3.org/2000/svg" preserveAspectRatio="xMidYMid slice", _role="img" focusable="false",<rect _width="100%", _height="100%" fill="#777")</svg>""",
-                        div( _class="container").html(
-                            div( _class="carousel-caption").html(
+                        div(_class="container").html(
+                            div(_class="carousel-caption").html(
                                 h1("Another example headline."),
                                 p("Cras justo odio, dapibus ac facilisis in, egestas eget quam. Donec id elit non mi porta gravida at eget metus. Nullam id dolor id nibh ultricies vehicula ut id elit."),
                                 p(a("Learn more", _class="btn btn-lg btn-primary", _href="#", _role="button"))
                             )
                         )
                     ),
-                    div( _class="carousel-item").html(
+                    div(_class="carousel-item").html(
                         """<svg _class="bd-placeholder-img", _width="100%", _height="100%" xmlns="http://www.w3.org/2000/svg" preserveAspectRatio="xMidYMid slice", _role="img" focusable="false",<rect _width="100%", _height="100%" fill="#777")</svg>""",
-                        div( _class="container").html(
-                            div( _class="carousel-caption text-right").html(
+                        div(_class="container").html(
+                            div(_class="carousel-caption text-right").html(
                                 h1("One more for good measure."),
                                 p("Cras justo odio, dapibus ac facilisis in, egestas eget quam. Donec id elit non mi porta gravida at eget metus. Nullam id dolor id nibh ultricies vehicula ut id elit."),
                                 p(a("Browse gallery", _class="btn btn-lg btn-primary", _href="#", _role="button"))
@@ -439,39 +436,39 @@ class domonicTestCase(unittest.TestCase):
                         )
                     )
                     ),
-                    a( _class="carousel-control-prev", _href="#myCarousel", _role="button", **{"_data-slide":"prev"}).html(
-                        span(**{"_aria-hidden":"true"}, _class="carousel-control-prev-icon"),
+                    a(_class="carousel-control-prev", _href="#myCarousel", _role="button", **{"_data-slide": "prev"}).html(
+                        span(**{"_aria-hidden": "true"}, _class="carousel-control-prev-icon"),
                         span("Previous", _class="sr-only")
                     ),
-                    a( _class="carousel-control-next", _href="#myCarousel", _role="button", **{"_data-slide":"next"}).html(
-                        span( _class="carousel-control-next-icon", **{"_aria-hidden":"true"}),
+                    a(_class="carousel-control-next", _href="#myCarousel", _role="button", **{"_data-slide": "next"}).html(
+                        span(_class="carousel-control-next-icon", **{"_aria-hidden": "true"}),
                         span("Next", _class="sr-only")
                     )
                 ),
-                div( _class="container marketing").html(
-                    div( _class="row").html(
-                    div( _class="col-lg-4").html(
+                div(_class="container marketing").html(
+                    div(_class="row").html(
+                    div(_class="col-lg-4").html(
                         """<svg _class="bd-placeholder-img rounded-circle", _width="140", _height="140" xmlns="http://www.w3.org/2000/svg" aria-label="Placeholder: 140x140" preserveAspectRatio="xMidYMid slice", _role="img" focusable="false",title(Placeholder)<rect _width="100%", _height="100%" fill="#777")<text x="50%" y="50%" fill="#777" dy=".3em">140x140</text></svg>""",
                         h2("Heading"),
                         p("Donec sed odio dui. Etiam porta sem malesuada magna mollis euismod. Nullam id dolor id nibh ultricies vehicula ut id elit. Morbi leo risus, porta ac consectetur ac, vestibulum at eros. Praesent commodo cursus magna."),
                         p(a("View details &raquo;", _class="btn btn-secondary", _href="#", _role="button"))
                     ),
-                    div( _class="col-lg-4").html(
+                    div(_class="col-lg-4").html(
                         """<svg _class="bd-placeholder-img rounded-circle", _width="140", _height="140" xmlns="http://www.w3.org/2000/svg" aria-label="Placeholder: 140x140" preserveAspectRatio="xMidYMid slice", _role="img" focusable="false",title(Placeholder)<rect _width="100%", _height="100%" fill="#777")<text x="50%" y="50%" fill="#777" dy=".3em">140x140</text></svg>""",
                         h2("Heading"),
                         p("Duis mollis, est non commodo luctus, nisi erat porttitor ligula, eget lacinia odio sem nec elit. Cras mattis consectetur purus sit amet fermentum. Fusce dapibus, tellus ac cursus commodo, tortor mauris condimentum nibh."),
                         p(a("View details &raquo;", _class="btn btn-secondary", _href="#", _role="button"))
                     ),
-                    div( _class="col-lg-4").html(
+                    div(_class="col-lg-4").html(
                         """<svg _class="bd-placeholder-img rounded-circle", _width="140", _height="140" xmlns="http://www.w3.org/2000/svg" aria-label="Placeholder: 140x140" preserveAspectRatio="xMidYMid slice", _role="img" focusable="false",title(Placeholder)<rect _width="100%", _height="100%" fill="#777")<text x="50%" y="50%" fill="#777" dy=".3em">140x140</text></svg>""",
                         h2("Heading"),
                         p("Donec sed odio dui. Cras justo odio, dapibus ac facilisis in, egestas eget quam. Vestibulum id ligula porta felis euismod semper. Fusce dapibus, tellus ac cursus commodo, tortor mauris condimentum nibh, ut fermentum massa justo sit amet risus."),
                         p(a("View details &raquo;", _class="btn btn-secondary", _href="#", _role="button")
                     ),
-                    hr( _class="featurette-divider"),
-                    div( _class="row featurette").html(
-                        div( _class="col-md-7").html(
-                            h2("First featurette heading.", span( _class="text-muted"), "It’ll blow your mind.", _class="featurette-heading"),
+                    hr(_class="featurette-divider"),
+                    div(_class="row featurette").html(
+                        div(_class="col-md-7").html(
+                            h2("First featurette heading.", span(_class="text-muted"), "It’ll blow your mind.", _class="featurette-heading"),
                             p("Donec ullamcorper nulla non metus auctor fringilla. Vestibulum id ligula porta felis euismod semper. Praesent commodo cursus magna, vel scelerisque nisl consectetur. Fusce dapibus, tellus ac cursus commodo.",
                             _class="lead")
                         ),
@@ -479,20 +476,20 @@ class domonicTestCase(unittest.TestCase):
                             _class="col-md-5"
                         )
                     ),
-                    hr( _class="featurette-divider"),
-                    div( _class="row featurette").html(
-                        div( _class="col-md-7 order-md-2").html(
-                            h2( "Oh yeah, it’s that good.", span( _class="text-muted"), "See for yourself.", _class="featurette-heading")),
+                    hr(_class="featurette-divider"),
+                    div(_class="row featurette").html(
+                        div(_class="col-md-7 order-md-2").html(
+                            h2("Oh yeah, it’s that good.", span(_class="text-muted"), "See for yourself.", _class="featurette-heading")),
                             p("Donec ullamcorper nulla non metus auctor fringilla. Vestibulum id ligula porta felis euismod semper. Praesent commodo cursus magna, vel scelerisque nisl consectetur. Fusce dapibus, tellus ac cursus commodo.", _class="lead")
                         ),
-                        div( _class="col-md-5 order-md-1").html(
+                        div(_class="col-md-5 order-md-1").html(
                             """<svg _class="bd-placeholder-img bd-placeholder-img-lg featurette-image img-fluid mx-auto", _width="500", _height="500" xmlns="http://www.w3.org/2000/svg" aria-label="Placeholder: 500x500" preserveAspectRatio="xMidYMid slice", _role="img" focusable="false",title(Placeholder)<rect _width="100%", _height="100%" fill="#eee")<text x="50%" y="50%" fill="#aaa" dy=".3em">500x500</text></svg>"""
                         )
                     ),
-                    hr( _class="featurette-divider"),
-                    div( _class="row featurette").html(
-                    div( _class="col-md-7").html(
-                        h2("Checkmate.", "And lastly, this one.", span( _class="text-muted"), _class="featurette-heading" ),
+                    hr(_class="featurette-divider"),
+                    div(_class="row featurette").html(
+                    div(_class="col-md-7").html(
+                        h2("Checkmate.", "And lastly, this one.", span(_class="text-muted"), _class="featurette-heading"),
                         p("Donec ullamcorper nulla non metus auctor fringilla. Vestibulum id ligula porta felis euismod semper. Praesent commodo cursus magna, vel scelerisque nisl consectetur. Fusce dapibus, tellus ac cursus commodo.",
                         _class="lead")
                     ),
@@ -500,24 +497,23 @@ class domonicTestCase(unittest.TestCase):
                         _class="col-md-5"
                         )
                     ),
-                    hr( _class="featurette-divider"),
-                    footer( _class="container").html(
+                    hr(_class="featurette-divider"),
+                    footer(_class="container").html(
                         p("Back to top", a(_href="#"), _class="float-right"),
                         p("&copy; 2017-2020 Company, Inc. &middot;", a("Privacy", _href="#"), "&middot;", a("Terms", _href="#"))
                     )
                     ),
-                    script( _src="/docs/5.0/dist/js/bootstrap.bundle.min.js", _integrity="sha384-12345", _crossorigin="anonymous" )
+                    script(_src="/docs/5.0/dist/js/bootstrap.bundle.min.js", _integrity="sha384-12345", _crossorigin="anonymous")
                     )
                 )
             )
         )
-        '''
         # print(render(test,'bs5_test_carousel.html'))
-        # print(render(test))
+        print(render(test))
         pass
 
 
-
+    @silence
     def test_domonic_render_bs5_dashboard(self):
         root = html(_lang="en")
         test = root.html(
@@ -560,13 +556,13 @@ class domonicTestCase(unittest.TestCase):
                     button(span(_class="navbar-toggler-icon"), 
                         _class="navbar-toggler position-absolute d-md-none collapsed",
                         _type="button", 
-                        **{"_data-toggle":"collapse"}, 
-                        **{"_data-target":"#sidebarMenu"}, 
-                        **{"_aria-controls":"sidebarMenu"}, 
-                        **{"_aria-expanded":"false"}, 
-                        **{"_aria-label":"Toggle navigation"}
+                        **{"_data-toggle": "collapse"}, 
+                        **{"_data-target": "#sidebarMenu"}, 
+                        **{"_aria-controls": "sidebarMenu"}, 
+                        **{"_aria-expanded": "false"}, 
+                        **{"_aria-label": "Toggle navigation"}
                     ),
-                    input(_class="form-control form-control-dark w-100", _type="text", _placeholder="Search", **{"_aria-label":"Search"}).html(
+                    input(_class="form-control form-control-dark w-100", _type="text", _placeholder="Search", **{"_aria-label": "Search"}).html(
                         ul(_class="navbar-nav px-3").html(
                             li(a("Sign out",_class="nav-link", _href="#"), _class="nav-item text-nowrap")
                         )
@@ -577,52 +573,52 @@ class domonicTestCase(unittest.TestCase):
                             div(_class="position-sticky pt-3").html(
                                 ul(_class="nav flex-column").html(
                                     li(
-                                        a(span(**{"_data-feather":"home"}), "Dashboard", _class="nav-link active", **{"_aria-current":"page"}, _href="#"),
+                                        a(span(**{"_data-feather": "home"}), "Dashboard", _class="nav-link active", **{"_aria-current": "page"}, _href="#"),
                                         _class="nav-item"
                                     ),
                                     li(
-                                        a(span(**{"_data-feather":"file"}), "Orders", _class="nav-link", _href="#"),
+                                        a(span(**{"_data-feather": "file"}), "Orders", _class="nav-link", _href="#"),
                                         _class="nav-item"
                                     ),
                                     li(
-                                        a(span(**{"_data-feather":"shopping-cart"}), "Products", _class="nav-link", _href="#"),
+                                        a(span(**{"_data-feather": "shopping-cart"}), "Products", _class="nav-link", _href="#"),
                                         _class="nav-item"
                                     ),
                                     li(
-                                        a(span(**{"_data-feather":"users"}), "Customers", _class="nav-link", _href="#"),
+                                        a(span(**{"_data-feather": "users"}), "Customers", _class="nav-link", _href="#"),
                                         _class="nav-item"
                                     ),
                                     li(
-                                        a(span(**{"_data-feather":"bar-chart-2"}), "Reports", _class="nav-link", _href="#"),
+                                        a(span(**{"_data-feather": "bar-chart-2"}), "Reports", _class="nav-link", _href="#"),
                                         _class="nav-item"
                                     ),
                                     li(
-                                        a(span(**{"_data-feather":"layers"}),"Integrations",_class="nav-link", _href="#"),
+                                        a(span(**{"_data-feather": "layers"}),"Integrations",_class="nav-link", _href="#"),
                                         _class="nav-item"
                                     )
                                 )
                             ),
                             h6(_class="sidebar-heading d-flex justify-content-between align-items-center px-3 mt-4 mb-1 text-muted").html(
                             span("Saved reports"),
-                                a(span(**{"_data-feather":"plus-circle"}, **{"_aria-label":"Add a new report"}),
+                                a(span(**{"_data-feather": "plus-circle"}, **{"_aria-label": "Add a new report"}),
                                     _class="link-secondary", _href="#")
                                 )
                             ),
                             ul(_class="nav flex-column mb-2").html(
                                 li(
-                                    a(span(**{"_data-feather":"file-text"}), "Current month", _class="nav-link", _href="#"),
+                                    a(span(**{"_data-feather": "file-text"}), "Current month", _class="nav-link", _href="#"),
                                     _class="nav-item"
                                 ),
                                 li(
-                                    a(span(**{"_data-feather":"file-text"}), "Last quarter", _class="nav-link", _href="#"),
+                                    a(span(**{"_data-feather": "file-text"}), "Last quarter", _class="nav-link", _href="#"),
                                     _class="nav-item"
                                 ),
                                 li(
-                                    a(span(**{"_data-feather":"file-text"}), "Social engagement", _class="nav-link", _href="#"),
+                                    a(span(**{"_data-feather": "file-text"}), "Social engagement", _class="nav-link", _href="#"),
                                     _class="nav-item"
                                 ),
                                 li(
-                                    a(span(**{"_data-feather":"file-text"}), "Year-end sale", _class="nav-link", _href="#"),
+                                    a(span(**{"_data-feather": "file-text"}), "Year-end sale", _class="nav-link", _href="#"),
                                     _class="nav-item"
                                 )
                             )
@@ -636,7 +632,7 @@ class domonicTestCase(unittest.TestCase):
                                     button("Share", _type="button", _class="btn btn-sm btn-outline-secondary"),
                                     button("Export", _type="button", _class="btn btn-sm btn-outline-secondary")
                                 ),
-                                button(span(**{"_data-feather":"calendar"}), "This week", _type="button", _class="btn btn-sm btn-outline-secondary dropdown-toggle")
+                                button(span(**{"_data-feather": "calendar"}), "This week", _type="button", _class="btn btn-sm btn-outline-secondary dropdown-toggle")
                             )
                         ),
                         canvas(_class="my-4 w-100", _id="myChart", _width="900", _height="380"),
@@ -771,10 +767,10 @@ class domonicTestCase(unittest.TestCase):
                     )
                 )
             ),
-            script( _src="/docs/5.0/dist/js/bootstrap.bundle.min.js", _integrity="sha384-1234", _crossorigin="anonymous"),
-            script( _src="https://cdnjs.cloudflare.com/ajax/libs/feather-icons/4.24.1/feather.min.js", _integrity="sha384-1234", _crossorigin="anonymous"),
-            script( _src="https://cdnjs.cloudflare.com/ajax/libs/Chart.js/2.9.3/Chart.min.js", _integrity="sha384-1234", _crossorigin="anonymous" ),
-            script( _src="dashboard.js" )
+            script(_src="/docs/5.0/dist/js/bootstrap.bundle.min.js", _integrity="sha384-1234", _crossorigin="anonymous"),
+            script(_src="https://cdnjs.cloudflare.com/ajax/libs/feather-icons/4.24.1/feather.min.js", _integrity="sha384-1234", _crossorigin="anonymous"),
+            script(_src="https://cdnjs.cloudflare.com/ajax/libs/Chart.js/2.9.3/Chart.min.js", _integrity="sha384-1234", _crossorigin="anonymous"),
+            script(_src="dashboard.js")
         )
 
         # print(render(test,'bs5_test_dashboard.html'))
